#
# spec file for package iverilog
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           iverilog
Version:        11.0
Release:        1.12
%define major_ver 11
Summary:        Simulation and synthesis tool for IEEE-1364
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
URL:            http://iverilog.icarus.com/
Source:         ftp://icarus.com/pub/eda/verilog/v%{major_ver}/verilog-%{version}.tar.gz
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gperf
BuildRequires:  libbz2-devel
BuildRequires:  readline-devel
BuildRequires:  zlib-devel

%description
Icarus Verilog is a Verilog compiler that generates a variety of
engineering formats, including simulation. It strives to be true
to the IEEE-1364 standard.

%package        devel
Summary:        Icarus Verilog development files
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description    devel
This package contains necessary header files for Icarus Verilog

%prep
%setup -q -n verilog-%{version}

%build
%configure
%make_build

%install
%make_install
rm %{buildroot}/%{_libdir}/*.a
%fdupes -s %{buildroot}/%{_libdir}/ivl/

%check
make check

%files
%license COPYING
%doc README.txt BUGS.txt QUICK_START.txt ieee1364-notes.txt
%doc swift.txt netlist.txt t-dll.txt vpi.txt tgt-fpga/fpga.txt
%doc cadpli/cadpli.txt xilinx-hint.txt examples
%{_mandir}/man1/*
%{_bindir}/*
%{_libdir}/ivl/

%files devel
%{_includedir}/*

%changelog
* Tue Sep 29 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 11.0
  * No changelog available
  * Remove obsolete patches:
    + Fix-makefile-rules-for-header-files-generated-by-bison.patch
    + fix-cfparse-include-order-causing-lto-type-mismatch.patch
- Spec cleanup
* Fri Jul 26 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 10.2
  * No changelog available
- Fix build with bison 3.4.1, add
  Fix-makefile-rules-for-header-files-generated-by-bison.patch
- Fix LTO type mismatch, add
  fix-cfparse-include-order-causing-lto-type-mismatch.patch
- Spec cleanup:
  * remove defattr, use license macro
  * Update License to SPDX format
  * Drop irrelevant mingw.txt from docs
* Mon Mar 21 2016 dmitry_r@opensuse.org
- Update to version 10.1
  * No changelog available
* Fri Nov 20 2015 dmitry_r@opensuse.org
- Update to version 10.0
  * No changelog available
* Thu Feb 13 2014 dmitry_r@opensuse.org
- Update to version 0.9.7
  * no changelog available
  * removed obsolete iverilog-0.9.6-fix-licensing-issues.patch
* Mon Oct  1 2012 dmitry_r@opensuse.org
- Fix license issues [bnc#782970, bnc#782972]
  * iverilog-0.9.6-fix-licensing-issues.patch
* Sat Sep 29 2012 dmitry_r@opensuse.org
- Update to version 0.9.6
  * bug-fix release
* Thu Aug 30 2012 scorot@free.fr
- fix files list to avoid debuginfo failure on i586
* Wed Aug 29 2012 arun@gmx.de
- added devel package
- updated url
- updated license name
- removed static *.a libraries during install
* Sun Jul  8 2012 scorot@free.fr
- spec file cleanup and reformating
* Sun Nov 20 2011 werner.ho@gmx.de
- new version 0.9.5
* Tue Oct 12 2010 Werner Hoch <werner.ho@gmx.de> - 0.9.3
- new version 0.9.3
* Sun Jun  6 2010 Werner Hoch <werner.ho@gmx.de> - 0.9.2
- new version 0.9.2
* Sun Apr 19 2009 Werner Hoch <werner.ho@gmx.de> - 0.9.1
- new version 0.9.1
* Fri Jan  2 2009 Werner Hoch <werner.ho@gmx.de> - 0.8.7
- new version 0.8.7
- removed 32 bit support for x86_64
- new gcc43 patch, new destdir patch
* Sun Sep 21 2008 Werner Hoch <werner.ho@gmx.de> - 0.8.6
- fixes for openSUSE 11.0
- patch for gcc-4.3.0
* Tue Nov 27 2007 Werner Hoch <werner.ho@gmx.de>
- new version 0.8.6
- added libbz2.a file from i586 arch (libbz2-devel-1.0.4) and bz2lib patch
* Sat Jul 28 2007 Werner Hoch <werner.ho@gmx.de>
- new version 0.8.5
* Sat Mar 24 2007 Werner Hoch <werner.ho@gmx.de>
- new version 0.8.4
* Wed Feb  7 2007 Werner Hoch <werner.ho@gmx.de>
- added fix for openSUSE 10.2 x86_64, fix by Günter Dannoritzer dannoritzer@web.de
* Sat Nov  4 2006 Werner Hoch <werner.ho@gmx.de>
- added BuildRequires gcc-c++-32bit for SuSE versions > 1010
* Tue Oct 31 2006 Werner Hoch <werner.ho@gmx.de>
- added readline-32bit to Buildrequires of arch=x86_64 (missing in readline-devel-32bit on SuSE 10.0 and 9.3)
* Sat Oct 28 2006 Werner Hoch <werner.ho@gmx.de>
- initial build version 0.8.3
- spec file originaly written by Stephen Williams <steve@icarus.com>
